@@ -1,35 +1,31 @@
-import os
-try:
-    _s = os.environ['DJANGO_SETTINGS_MODULE']
-except KeyError:
-    # DJANGO_SETTINGS_MODULE should have been set by now, if not, we must be in test mode
-    os.environ['DJANGO_SETTINGS_MODULE'] = 'bootup.testsettings'
+__version__ = '1.0.1'
 
 from django.conf import settings
 from django.db.models import signals
 from django.contrib.auth.management import create_superuser
 from django.contrib.auth import models as auth_app
 from django.contrib.auth.models import User
-from .profiles import create_profile, delete_profile
-from .bootup import bootup
+from profiles import create_profile, delete_profile
+from bootup import bootup
 
 # disable syncdb from prompting you to create a superuser.
 # we need a superuser, so we let bootup create it for us.
 signals.post_syncdb.disconnect(
     create_superuser,
     sender=auth_app,
-    dispatch_uid = "django.contrib.auth.management.create_superuser")
+    dispatch_uid = "django.contrib.auth.management.create_superuser"
+)
 
 # bootstrap our project (site) after syncdb
 signals.post_syncdb.connect(bootup)
 
-# when a user is created and saved to db, a profile for that user is created
+# when a user is created and saved to db, a profile for that user is also created
 if getattr(settings, 'AUTH_PROFILE_MODULE', False):
     # latch on user creation if flag is set
     if getattr(settings, 'BOOTUP_USER_PROFILE_AUTO_CREATE', False):
         signals.post_save.connect(create_profile, sender=User)
 
-        # latch on user deletion if flag if both (create & delete) flags are set
+        # latch on user deletion flag if both (create & delete) are set
         if getattr(settings, 'BOOTUP_USER_PROFILE_AUTO_DELETE', False):
             signals.post_delete.connect(delete_profile, sender=User)
 
