@@ -1,7 +1,7 @@
 from django.conf import settings
-from .fixtures import load_fixtures
-from .users import setup_superuser
-from .sites import setup_sites
+from fixtures import load_fixtures
+from users import setup_superuser
+from sites import setup_sites
 
 
 # bootstrap the site with all info but only after the completion of syncdb
@@ -10,8 +10,7 @@ def bootup(sender, **kwargs):
     After syncdb, bootup makes the required adjustements in order to prepare and secure the site
     """
     # only trigger if we have installed the last app
-    # print kwargs['app'].__name__ + " -- " + settings.INSTALLED_APPS[-1]+".models"
-    if kwargs['app'].__name__ == settings.INSTALLED_APPS[-1]+".models":
+    if kwargs['app'].__name__ == '{0}.models'.format(settings.INSTALLED_APPS[-1]):
 
         # 1. load the fixtures
         load_fixtures()
