@@ -1,5 +1,5 @@
 from django.conf import settings
-from .utils import fetch_model
+from util import fetch_model
 
 def get_profile_model():
     """
@@ -13,6 +13,7 @@ def get_profile_model():
             return profile_model
     return None
 
+
 def create_profile(sender, instance, created, **kwargs):
     """
     Create a matching profile whenever a user object is created.
@@ -27,6 +28,7 @@ def create_profile(sender, instance, created, **kwargs):
             except:
                 pass
 
+
 def delete_profile(sender, instance, **kwargs):
     """
     Delete a matching profile whenever a user object is deleted.
