@@ -4,10 +4,10 @@ from django.contrib.auth.models import User
 
 def setup_superuser(username, password, email):
     """
-    Create or update and account of type supersuer (fist user of this site)
+    Create or update and account of type supersuer (likely the first user of this site)
     """
     if username and password and email:
-        user, created = User.objects.get_or_create(pk=1)
+        user, created = User.objects.get_or_create(email=email)
         if user:
             user.username = username
             user.set_password(password)
@@ -15,4 +15,4 @@ def setup_superuser(username, password, email):
             user.is_staff = True
             user.is_active = True
             user.is_superuser = True
-            user.save()
\ No newline at end of file
+            user.save()
